From: "J.A. Magallon" <jamagallon@able.es>
To: khali@linux-fr.org
Cc: linux-kernel@vger.kernel.org, lm-sensors@lm-sensors.org
Subject: Re: 2.6.14-rc2-mm2
Date: Fri, 30 Sep 2005 01:09:31 +0200 [thread overview]
Message-ID: <20050930010931.5beb174e@werewolf.able.es> (raw)
In-Reply-To: <20050929143732.59d22569.akpm@osdl.org>
[-- Attachment #1: Type: text/plain, Size: 3575 bytes --]
On Thu, 29 Sep 2005 14:37:32 -0700, Andrew Morton <akpm@osdl.org> wrote:
>
> ftp://ftp.kernel.org/pub/linux/kernel/people/akpm/patches/2.6/2.6.14-rc2/2.6.14-rc2-mm2/
>
> (temp copy at http://www.zip.com.au/~akpm/linux/patches/stuff/2.6.14-rc2-mm2.gz)
>
I still need this to make my sensors work. I collected it from the list, heard
people say it was not the proper solution, but without this it still doesn't work.
No sensors.
Another issue. Is there any divisor value for fans hardcoded intially ?
I have 3 fans in my mobo, and 2 report 0 RPM until I put the divisor at 8
This fans are two for the xeons, and one for the box. Strangely, the fans that
are misread are the one for the board and one of the xeons ?
And more, my board has 2 more fan sensors, but the driver can only see 3. Any idea ?
(Asus PC-DL Deluxe).
TIA
diff -urN linux-2.6.13-5bca.dist/drivers/hwmon/w83627hf.c linux-2.6.13-5bca/drivers/hwmon/w83627hf.c
--- linux-2.6.13-5bca.dist/drivers/hwmon/w83627hf.c 2005-09-06 13:50:03.000000000 +0200
+++ linux-2.6.13-5bca/drivers/hwmon/w83627hf.c 2005-09-07 19:54:08.000000000 +0200
@@ -142,12 +142,16 @@
#define WINB_BASE_REG 0x60
/* Constants specified below */
-/* Length of ISA address segment */
-#define WINB_EXTENT 8
+/* Alignment of ISA address */
+#define WINB_ALIGNMENT ~7
-/* Where are the ISA address/data registers relative to the base address */
-#define W83781D_ADDR_REG_OFFSET 5
-#define W83781D_DATA_REG_OFFSET 6
+/* Offset & size of I/O region we are interested in */
+#define WINB_REGION_OFFSET 5
+#define WINB_REGION_SIZE 2
+
+/* Where are the ISA address/data registers relative to the region start */
+#define W83781D_ADDR_REG_OFFSET 0
+#define W83781D_DATA_REG_OFFSET 1
/* The W83781D registers */
/* The W83782D registers for nr=7,8 are in bank 5 */
@@ -981,7 +985,7 @@
superio_select(W83627HF_LD_HWM);
val = (superio_inb(WINB_BASE_REG) << 8) |
superio_inb(WINB_BASE_REG + 1);
- *addr = val & ~(WINB_EXTENT - 1);
+ *addr = val & WINB_ALIGNMENT;
if (*addr == 0 && force_addr == 0) {
superio_exit();
return -ENODEV;
@@ -998,11 +1002,13 @@
struct w83627hf_data *data;
int err = 0;
const char *client_name = "";
+ unsigned short addr;
if(force_addr)
- address = force_addr & ~(WINB_EXTENT - 1);
+ address = force_addr & WINB_ALIGNMENT;
+ addr = address + WINB_REGION_OFFSET;
- if (!request_region(address, WINB_EXTENT, w83627hf_driver.name)) {
+ if (!request_region(addr, WINB_REGION_SIZE, w83627hf_driver.name)) {
err = -EBUSY;
goto ERROR0;
}
@@ -1049,7 +1055,7 @@
new_client = &data->client;
i2c_set_clientdata(new_client, data);
- new_client->addr = address;
+ new_client->addr = addr;
init_MUTEX(&data->lock);
new_client->adapter = adapter;
new_client->driver = &w83627hf_driver;
@@ -1148,7 +1154,7 @@
ERROR2:
kfree(data);
ERROR1:
- release_region(address, WINB_EXTENT);
+ release_region(addr, WINB_REGION_SIZE);
ERROR0:
return err;
}
@@ -1163,7 +1169,7 @@
if ((err = i2c_detach_client(client)))
return err;
- release_region(client->addr, WINB_EXTENT);
+ release_region(client->addr, WINB_REGION_SIZE);
kfree(data);
return 0;
--
J.A. Magallon <jamagallon()able!es> \ Software is like sex:
werewolf!able!es \ It's better when it's free
Mandriva Linux release 2006.0 (2006 rc2) for i586
Linux 2.6.13-jam7 (gcc 4.0.1 (4.0.1-5mdk for Mandriva Linux release 2006.0))
[-- Attachment #2: Type: application/pgp-signature, Size: 189 bytes --]
next prev parent reply other threads:[~2005-09-29 23:08 UTC|newest]
Thread overview: 42+ messages / expand[flat|nested] mbox.gz Atom feed top
2005-09-29 21:37 2.6.14-rc2-mm2 Andrew Morton
2005-09-29 21:46 ` 2.6.14-rc2-mm2 Alexandre Buisse
2005-09-29 22:51 ` 2.6.14-rc2-mm2 Michal Piotrowski
2005-09-29 23:00 ` 2.6.14-rc2-mm2 Aurelien Francillon
2005-09-29 22:56 ` 2.6.14-rc2-mm2 Andrew Morton
2005-09-29 22:08 ` 2.6.14-rc2-mm2 Alexandre Buisse
2005-09-29 23:40 ` 2.6.14-rc2-mm2 Michal Piotrowski
2005-09-29 23:54 ` 2.6.14-rc2-mm2 Brice Goglin
2005-09-30 8:45 ` 2.6.14-rc2-mm2 Laurent Riffard
2005-09-30 9:20 ` 2.6.14-rc2-mm2 Alexander Zarochentsev
2005-09-30 10:10 ` 2.6.14-rc2-mm2 Laurent Riffard
2005-09-29 23:51 ` 2.6.14-rc2-mm2 Hans Reiser
2005-09-29 22:47 ` 2.6.14-rc2-mm2 Michal Piotrowski
2005-09-29 23:18 ` 2.6.14-rc2-mm2 Antonino A. Daplas
2005-09-29 23:25 ` 2.6.14-rc2-mm2 Andrew Morton
2005-09-29 23:45 ` 2.6.14-rc2-mm2 Antonino A. Daplas
2005-09-29 23:47 ` 2.6.14-rc2-mm2 Michal Piotrowski
2005-09-29 23:48 ` 2.6.14-rc2-mm2 Grant Coady
2005-09-29 23:27 ` 2.6.14-rc2-mm2 Michal Piotrowski
2005-09-29 23:09 ` J.A. Magallon [this message]
2005-09-30 2:16 ` 2.6.14-rc2-mm2 Grant Coady
2005-10-01 18:16 ` 2.6.14-rc2-mm2 Jean Delvare
2005-09-29 23:26 ` 2.6.14-rc2-mm2 Mark Knecht
2005-09-29 23:49 ` 2.6.14-rc2-mm2 Andrew Morton
2005-09-29 23:58 ` 2.6.14-rc2-mm2 Mark Knecht
2005-09-30 10:06 ` [PATCH -mm] s390: fix TIMER_MAGIC breakage Alexey Dobriyan
2005-09-30 14:36 ` 2.6.14-rc2-mm2 Martin J. Bligh
2005-09-30 16:54 ` 2.6.14-rc2-mm2 Badari Pulavarty
2005-09-30 17:15 ` 2.6.14-rc2-mm2 Grant Wilson
2005-09-30 18:49 ` 2.6.14-rc2-mm2 (PHY reset until link up) Dominik Karall
2005-09-30 19:07 ` Andrew Morton
2005-09-30 19:32 ` [patch 2.6.14-rc2 1/1] r8169: tone down the r8169 driver Francois Romieu
2005-09-30 20:15 ` 2.6.14-rc2-mm2 (PHY reset until link up) Francois Romieu
2005-09-30 19:36 ` 2.6.14-rc2-mm2 Mickael Marchand
2005-10-04 21:42 ` 2.6.14-rc2-mm2 Mickael Marchand
2005-09-30 19:56 ` 2.6.14-rc2-mm2 alexs
2005-09-30 22:02 ` reiser4 compilation fix [ was: 2.6.14-rc2-mm2] Alexander Zarochentsev
2005-09-30 22:23 ` Stephen Hemminger
2005-10-01 4:56 ` [PATCH] mips: add missing semicolon Yoichi Yuasa
2005-10-01 16:52 ` 2.6.14-rc2-mm2 (dma_timer_expiry) Dominik Karall
2005-10-02 20:06 ` 2.6.14-rc2-mm2 (NULL pointer) Dominik Karall
2005-10-02 20:45 ` Greg KH
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20050930010931.5beb174e@werewolf.able.es \
--to=jamagallon@able.es \
--cc=khali@linux-fr.org \
--cc=linux-kernel@vger.kernel.org \
--cc=lm-sensors@lm-sensors.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®